import sys, os, string
import bsddb

sys.path.append(os.path.expanduser('~/.roundtable-lab'))

import config

authdb = os.path.join(config.etcdir, 'auth.db')
prefdb = os.path.join(config.etcdir, 'pref.db')

### bsddb database interface

def setAuthInfo(user, realname, password, emailaddr):
  """We add or update a user"""
  #authdb = config.authdb
  authdb = os.path.join(config.etcdir, 'auth.db')
  authdb = bsddb.btopen(authdb, 'c')
  prefdb = os.path.join(config.etcdir, 'pref.db')
  prefdb = bsddb.btopen(prefdb, 'c')

  authdb[user] = string.join((realname, password, emailaddr), ';')
  #prefdb[user] = ''
  setPrefs(user, sublist='', threadstyle='basic')

  authdb.sync()
  prefdb.sync()

def getAuthInfo(user):
  """Returns the real name, md5 password and email address"""
  #authdb = config.authdb
  authdb = os.path.join(config.etcdir, 'auth.db')
  authdb = bsddb.btopen(authdb, 'r')

  realname, password, emailaddr = string.split(authdb[user], ';')

  return realname, password, emailaddr

def hasUser(user):
  """Do we have a user by that name?"""
  #authdb = config.authdb
  authdb = os.path.join(config.etcdir, 'auth.db')
  authdb = bsddb.btopen(authdb, 'r')

  if authdb.has_key(user):
    return 1
  else:
    return 0

def getPrefs(user):
  """Returns the preferences in dictionary format"""
  #prefdb = config.prefdb
  prefdb = os.path.join(config.etcdir, 'pref.db')
  prefdb = bsddb.btopen(prefdb, 'r')

  prefdict = ({})

  prefs = prefdb[user]
  prefs = string.split(prefs, ';')

  for pref in prefs:
    if 'sublist=' in pref:
      sublist = string.split(pref, '=', 1)[1]
      sublist = string.split(sublist, ',')
      if not isinstance(sublist, list):
        sublist = [sublist]

      prefdict['sublist'] = sublist

    if 'threadstyle=' in pref:
      prefdict['threadstyle'] = string.split(pref, '=', 1)[1]

  return prefdict

def setPrefs(user, **prefs):
  """Sets preferences"""
  #prefdb = config.prefdb
  prefdb = os.path.join(config.etcdir, 'pref.db')
  prefdb = bsddb.btopen(prefdb, 'c')

  prefdict = getPrefs(user)
  prefstring = ''

  for k, v in prefs.items():
    k = string.lower(k)

    if isinstance(v, list):
      v = string.join(v, ',')
    
    v = string.lower(v)

    prefdict[k] = v

  for k, v in prefdict.items():

    if isinstance(v, list):
      v = string.join(v, ',')
    
    prefstring = prefstring + k + '=' + v + ';'

  if prefstring[-1] == ';':
    prefstring = prefstring[:-1]

  prefdb[user] = prefstring

  prefdb.sync()

def putMessage(name, mid, content):
  """Insert a message into the database"""
  msgdb = os.path.join(config.etcdir, name + '.db')
  msgdb = bsddb.btopen(msgdb, 'c')

  msgdb[mid] = content

  msgdb.sync()

def getMessages(name):
  """Gets the messages from the database"""
  msgdb = os.path.join(config.etcdir, name + '.db')
  msgdb = bsddb.btopen(msgdb, 'r')

  return msgdb

